Classification Metrics — imbalanced-ensemble 0.1.0 documentation

# Classification Metrics

The `imbalanced_ensemble.metrics` module includes score functions, performance metrics and pairwise metrics and distance computations.

`sensitivity_specificity_support`(y_true, …) | Compute sensitivity, specificity, and support for each class
`sensitivity_score`(y_true, y_pred, *[, …]) | Compute the sensitivity
`specificity_score`(y_true, y_pred, *[, …]) | Compute the specificity
`geometric_mean_score`(y_true, y_pred, *[, …]) | Compute the geometric mean.
`make_index_balanced_accuracy`(*[, alpha, squared]) | Balance any scoring function using the index balanced accuracy
`classification_report_imbalanced`(y_true, …) | Build a classification report based on metrics used with imbalanced dataset
`macro_averaged_mean_absolute_error`(y_true, …) | Compute Macro-Averaged Mean Absolute Error (MA-MAE) for imbalanced ordinal classification.